<?php
/**
 * The Ulaform script to generate the HTML to display a form in an external
 * HTML page.
 *
 * $Horde: ulaform/genhtml.php,v 1.27 2007/01/02 12:49:11 jan Exp $
 *
 * Copyright 2003-2007 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Marko Djukic <marko@oblo.com>
 */

@define('ULAFORM_BASE', dirname(__FILE__));
require_once ULAFORM_BASE . '/lib/base.php';
require_once 'Horde/Form/Action.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin()) {
    Horde::authenticationFailureRedirect();
}

/* Get some variables. */
$changed_type = false;
$html = '';
$vars = Variables::getDefaultVariables();
$formname = $vars->get('formname');
$form_id = $vars->get('form_id');
$type = $vars->get('type');
$old_type = $vars->get('old_type');

/* Check if type has been changed. */
if ($type != $old_type && $formname) {
    $changed_type = true;
    $notification->push(_("Changed embed type."), 'horde.message');
}

/* Fetch the form details and set a nice title. */
$form_details = $ulaform->getForm($form_id);
$title = sprintf(_("HTML Generation for \"%s\""), $form_details['form_name']);

$form = new Horde_Form($vars, $title);
$form->useToken(false);

/* Set up the form. */
$form->setButtons(_("Generate HTML"));
$form->addHidden('', 'form_id', 'int', false);
$form->addHidden('', 'old_type', 'text', false);

$embed_types = array('php_pear' => _("PHP using PEAR classes"), 'iframe' => _("iframe"));
$v = &$form->addVariable(_("Select how you wish to embed the form"), 'type', 'enum', true, false, null, array($embed_types, true));
$v->setAction(Horde_Form_Action::factory('submit'));

switch ($type) {
case 'php_pear':
    break;

case 'iframe':
    $form->addVariable(_("Name"), 'params[name]', 'text', true, false);
    $form->addVariable(_("Height"), 'params[height]', 'int', false, false);
    $form->addVariable(_("Width"), 'params[width]', 'int', false, false);
    break;
}

/* Set up the gateway choice fields. */
$vars->set('old_type', $type);

/* Check if submitted and validate. */
if ($formname && !$changed_type) {
    $form->validate($vars);

    if ($form->isValid()) {
        $form->getInfo($vars, $info);
        switch ($type) {
        case 'php_pear':
            $html = array(
                '&lt;?php',
                '$options[\'method\'] = \'post\';',
                '$data = $_POST;',
                '$data[\'form_params\'][\'url\'] = $_SERVER[\'SCRIPT_URI\'];',
                '$data[\'form_params\'][\'embed\'] = \'php\';',
                '$data[\'form_id\'] =  ' . $info['form_id'] . ';',
                'require_once \'HTTP/Request.php\';',
                '$http = new HTTP_Request(\'' . Horde::applicationUrl('display.php', true, -1) . '\', $options);',
                '$http->addRawPostData($data);',
                '$http->sendRequest();',
                'if ($http->getResponseCode() != 200) echo \'Form not available.\';',
                'else echo $http->getResponseBody();',
                '?>',
            );
            break;

        case 'iframe':
            $html = array(
                        sprintf('&lt;iframe src="%s" name="%s" %s%s hspace="2" vspace="2" scrolling="auto" marginwidth="5" marginheight="5" frameborder="0">&lt;/iframe>',
                                Util::addParameter(Horde::applicationUrl('display.php', true, -1), 'form_id', $info['form_id']),
                                $info['params']['name'],
                                ($info['params']['width'] ? 'width="' . $info['params']['width'] . '" ' : ''),
                                ($info['params']['height'] ? 'height="' . $info['params']['height'] . '" ' : '')));
            break;
        }
    }
}

/* Render the form. */
$template->set('inputform', Util::bufferOutput(array($form, 'renderActive'), new Horde_Form_Renderer(), $vars, 'genhtml.php', 'post'));
$template->set('html', $html, true);
$template->set('menu', Ulaform::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

Horde::addScriptFile('stripe.js', 'horde', true);
require ULAFORM_TEMPLATES . '/common-header.inc';
echo $template->fetch(ULAFORM_TEMPLATES . '/genhtml/genhtml.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
